@@ -190,7 +190,7 @@ class Graph(Resource):
                 if not resources:resources.add(Resource(dictionary = {str(_p): {_o}}, uri = _s))
                 for resource in resources:
                     if _s == resource.uri:
-                        resource.add_value(str(_p), str(_o))
+                        resource.add_value(str(_p), _o)
         return resources
     resources = property(to_resources)
 
