@@ -18,7 +18,7 @@ FOAF = Namespace('http://xmlns.com/foaf/0.1/')
 OWL = Namespace('http://www.w3.org/2002/07/owl#')
 RDF = Namespace('http://www.w3.org/1999/02/22-rdf-syntax-ns#')
 RDFS = Namespace('http://www.w3.org/2000/01/rdf-schema#')
-SMTK = Namespace('https://raw.githubusercontent.com/semantykcom/Semantyk/master/Archive/archive.ttl')
+SMTK = Namespace('https://raw.githubusercontent.com/semantykcom/Semantyk/master/Archive/archive.ttl/')
 SKOS = Namespace('http://www.w3.org/2004/02/skos/core#')
 XSD = Namespace('http://www.w3.org/2001/XMLSchema#')
 VOID = Namespace('http://rdfs.org/ns/void#')
\ No newline at end of file
